.. _releasenotes:

Release Notes
=============

.. toctree::
    :maxdepth: 1

    releases/1.7.1.rst
    releases/1.7.0.rst
    releases/1.6.0.rst
    releases/1.5.1.rst
    releases/1.5.0.rst
    releases/1.4.0.rst
    releases/1.3.1.rst
    releases/1.3.0.rst
    releases/1.2.3.rst
    releases/1.2.2.rst
    releases/1.2.1.rst
    releases/1.2.0.rst
    releases/1.1.1.rst
    releases/1.1.0.rst
    releases/1.0.1.rst
    releases/1.0.0.rst
